@@ -1,10 +1,12 @@
 import wsgiref.simple_server as serv
 import _thread
 from cgi import parse_qs
+import traceback
 class app:
     def __init__(self,handleClass):
         self.handleClass=handleClass
     def run(self,host,port,debug=True):
+        self.debug=debug
         print("• Serving HTTP on %s:%d"%(host,port))
         print("\033[5;41;33m• This is just a development server. Please do not use in production.\033[0m")
         with serv.make_server(host,port,self) as server:
@@ -18,5 +20,11 @@ class app:
         query=parse_qs(environ['QUERY_STRING'])
         del query["method"]
         query={x:query[x][0] for x in query}
-        start_response("200 OK",[])
-        return [function(*environ['PATH_INFO'].split("/")[1:],**query).encode()]
\ No newline at end of file
+        try:
+            res=function(environ,*environ['PATH_INFO'].split("/")[1:],**query)
+            start_response("200 OK",res[1])
+        except Exception as e:
+            if self.debug:
+                res=[traceback.format_exc().encode()]
+                start_response("500 Server Error",[])
+        return [res[0].encode()]
\ No newline at end of file
